@@ -72,6 +72,8 @@ class DownloadService:
         ]
         # Collects the total size of the files that needs to be downloaded.
         self.total_to_download = 0
+        self.last_threads_total_downloaded = 0
+        self.last_status_timestamp = time.time()
         self.total_files = 0
 
         # delete files, that should be deleted
@@ -81,6 +83,7 @@ class DownloadService:
             self.ssl_context = ssl._create_unverified_context()
         else:
             self.ssl_context = ssl.create_default_context(cafile=certifi.where())
+        self.skip_cert_verify = skip_cert_verify
 
         # Prepopulate queue with any files that were given
         for course in self.courses:
@@ -99,6 +102,7 @@ class DownloadService:
                             self.thread_report,
                             self.fs_lock,
                             self.ssl_context,
+                            self.skip_cert_verify,
                             self.options,
                         )
                     )
@@ -144,12 +148,11 @@ class DownloadService:
         print('\n' * (len(self.threads)), end='')
         old_status_message = ''
         while not self._downloader_complete():
-            time.sleep(0.1)
-
             new_status_message = self._get_status_message()
             if old_status_message != new_status_message:
                 print(new_status_message, end='')
                 old_status_message = new_status_message
+            time.sleep(0.5)
 
         self._clear_status_message()
         self._log_failures()
@@ -195,17 +198,17 @@ class DownloadService:
 
         threads_status_message = ''
         threads_total_downloaded = 0
-        add_empty_line = 0
         for thread in self.threads:
-            if not thread.is_alive():
-                add_empty_line += 1
-                continue
 
             i = thread.thread_id
             # A thread status contains it id and the progress
             # of the current file
             thread_percentage = self.thread_report[i]['percentage']
             thread_current_url = self.thread_report[i]['current_url']
+            if not thread.is_alive():
+                thread_percentage = 100
+                thread_current_url = 'Finished!'
+
             if len(thread_current_url) + 13 > limits.columns:
                 thread_current_url = thread_current_url[0 : limits.columns - 15] + '..'
 
@@ -218,9 +221,6 @@ class DownloadService:
                 self.total_to_download += extra_totalsize
                 self.thread_report[i]['extra_totalsize'] = -1
 
-        for i in range(add_empty_line):
-            threads_status_message += '\033[K\n'
-
         progressmessage += threads_status_message
 
         percentage = 100
@@ -237,21 +237,42 @@ class DownloadService:
 
         progressmessage_line += ' | Files: %5s/%5s' % (len(self.report['success']), self.total_files)
 
+        diff_to_last_status = threads_total_downloaded - self.last_threads_total_downloaded
+
+        speed = self.calc_speed(self.last_status_timestamp, time.time(), diff_to_last_status)
+        progressmessage_line += ' | ' + self.format_speed(speed)
+
         if len(progressmessage_line) > limits.columns:
             progressmessage_line = progressmessage_line[0 : limits.columns]
         progressmessage_line = '\033[K' + progressmessage_line
 
         progressmessage += progressmessage_line
 
+        self.last_status_timestamp = time.time()
+        self.last_threads_total_downloaded = threads_total_downloaded
+
         return progressmessage
 
+    @staticmethod
+    def calc_speed(start, now, bytes):
+        dif = now - start
+        if bytes <= 0 or dif < 0.001:  # One millisecond
+            return None
+        return float(bytes) / dif
+
+    @staticmethod
+    def format_speed(speed):
+        if speed is None:
+            return '%10s' % '---b/s'
+        return '%10s' % ('%s/s' % format_bytes(speed))
+
     def _clear_status_message(self):
-        print(f'\033[{len(self.threads)}A', end='')
+        print(f'\033[{len(self.threads)}A\r', end='')
 
         print('\033[K\n' * (len(self.threads)), end='')
         print('\033[K', end='')
 
-        print(f'\033[{len(self.threads)}A', end='')
+        print(f'\033[{len(self.threads)}A\r', end='')
 
     def _log_failures(self):
         """
