@@ -220,6 +220,7 @@ class URLTarget(object):
             msg = msg.replace('\033[K', '')
             msg = msg.replace('\033[0;31m', '')
             msg = msg.replace('\033[0m', '')
+            msg = re.sub('token=([a-zA-Z0-9]+)', 'censored_sensitive_data', msg)
 
             return msg
 
@@ -396,14 +397,15 @@ class URLTarget(object):
             )
         except (InvalidSchema, InvalidURL, MissingSchema):
             # don't download urls like 'mailto:name@provider.com'
-            logging.debug('Attempt is aborted because the URL has no correct format')
+            logging.debug('T%s - Attempt is aborted because the URL has no correct format', self.thread_id)
             self.success = True
             return False
 
         if not response.ok:
             # The URL reports an HTTP error, so we give up trying to download the URL.
             logging.warning(
-                'Stopping the attemp to download %s because of the HTTP ERROR %s',
+                'T%s - Stopping the attemp to download %s because of the HTTP ERROR %s',
+                self.thread_id,
                 self.file.content_fileurl,
                 response.status_code,
             )
